@@ -1,11 +1,11 @@
-from typing import IO, Optional
+import io
+from typing import Optional
 
 import requests
 from requests.adapters import HTTPAdapter
 from requests.packages.urllib3.util.retry import Retry
 
 from cached_path.schemes.scheme_client import SchemeClient
-from cached_path.tqdm import Tqdm
 
 RECOVERABLE_SERVER_ERROR_CODES = (502, 503, 504)
 
@@ -35,26 +35,35 @@ class HttpClient(SchemeClient):
     scheme = ("http", "https")
     recoverable_errors = SchemeClient.recoverable_errors + (RecoverableServerError,)
 
-    def get_etag(self) -> Optional[str]:
-        with session_with_backoff() as session:
-            response = session.head(self.resource, allow_redirects=True)
-        self.validate_response(response)
-        return response.headers.get("ETag")
+    def __init__(self, resource: str) -> None:
+        super().__init__(resource)
+        self._head_response = None
 
-    def get_resource(self, temp_file: IO) -> None:
+    @property
+    def head_response(self):
+        if self._head_response is None:
+            with session_with_backoff() as session:
+                response = session.head(self.resource, allow_redirects=True)
+            self.validate_response(response)
+            self._head_response = response
+            return self._head_response
+        else:
+            return self._head_response
+
+    def get_etag(self) -> Optional[str]:
+        return self.head_response.headers.get("ETag")
+
+    def get_size(self) -> Optional[int]:
+        content_length = self.head_response.headers.get("Content-Length")
+        return None if content_length is None else int(content_length)
+
+    def get_resource(self, temp_file: io.BufferedWriter) -> None:
         with session_with_backoff() as session:
             response = session.get(self.resource, stream=True)
             self.validate_response(response)
-            content_length = response.headers.get("Content-Length")
-            total = int(content_length) if content_length is not None else None
-            progress = Tqdm.tqdm(
-                unit="iB", unit_scale=True, unit_divisor=1024, total=total, desc="downloading"
-            )
             for chunk in response.iter_content(chunk_size=1024):
                 if chunk:  # filter out keep-alive new chunks
-                    progress.update(len(chunk))
                     temp_file.write(chunk)
-            progress.close()
 
     def validate_response(self, response):
         if response.status_code == 404:
